@@ -29,3 +29,11 @@ class ApplicationDispatcher(BaseDispatcher):
     def catch(interface):
         if getattr(interface.annotation, "__name__", None) == "GraiaMiraiApplication":
             return application.get()
+
+
+class EmptyDispatcher(BaseDispatcher):
+    mixin = [ApplicationDispatcher]
+
+    @staticmethod
+    def catch(interface):
+        pass
